Package 'kwb.dwa.m150'

Title: Read Sewer Condition Data according to DWA-M 150 XML format
Description: Read Sewer Condition Data according to DWA-M 150 XML format.
Authors: Hauke Sonnenberg [aut, cre] (ORCID: <https://orcid.org/0000-0001-9134-2871>), Kompetenzzentrum Wasser Berlin gGmbH [cph]
Maintainer: Hauke Sonnenberg <[email protected]>
License: MIT + file LICENSE
Version: 0.0.9.9000
Built: 2026-05-14 06:36:24 UTC
Source: https://github.com/KWB-R/kwb.dwa.m150

Help Index


Read XML file coded as described in DWA-M 150

Description

Read XML file coded as described in DWA-M 150

Usage

read_xml_dwa_m150(xml, encoding = "ISO-8859-1")

Arguments

xml

path to XML file

encoding

encoding used in the XML file, passed to read_xml

Value

list with elements fd, hg, hi, hz, each of which is a data frame containing the corresponding data as described in DWA-M150

Examples

xml <- system.file("extdata/example.xml", package = "kwb.dwa.m150")
content <- read_xml_dwa_m150(xml)

str(content)